require_relative '../spec_helper'
require 'tmpdir'

describe FBTiles do
  describe 'Database' do
    let(:db) do
      FBTiles::Database.new
    end

    let(:adapter) do
      db.adapter
    end

    describe '#create_schema!' do
      it 'has bounds table' do
        adapter.table_exists?(:bounds).must_equal true
      end

      it 'has datatypes table' do
        adapter.table_exists?(:datatypes).must_equal true
      end

      it 'has tiles table' do
        adapter.table_exists?(:tiles).must_equal true
      end

      it 'has datatypes index' do
        expected_index = { datatypes_idx: { unique: true, columns: [:datatype] } }
        
        adapter.indexes(:datatypes).must_equal expected_index
      end

      it 'has tiles index' do
        expected_index = { tiles_idx: { unique: false, columns: [:zoom_level, :tile_row, :tile_column] } }

        adapter.indexes(:tiles).must_equal expected_index
      end

      it 'has tile_zoom index' do
        expected_index = { tiles_zoom_idx: { unique: false, columns: [:zoom_level] } }
      end
    end

    it '.driver' do
      FBTiles::Database.driver.must_match(/\A(jdbc\:)?sqlite\z/)
    end

    it '#insert_bounds' do
      db.insert_bounds([{zoom: 0, collared: 0, maxX: 0, maxY: 0, minX: 0, minY: 0}])

      adapter[:bounds].first(zoom: 0, collared: 0, maxX: 0, maxY: 0, minX: 0, minY: 0).wont_be_nil
    end

  end
end
